Primary author:
---------------

* Vinod Kurup (@vkurup)


Other contributions from:
-------------------------

* Iztok Fister Jr (@firefly-cpp)
* Jason M. (@DaddyTheRunner)
* Adam Neumann (@noizwaves)
* Stephen Doyle (@stevedoyle)
* Loïs Taulelle (@ltaulell)
* Jan Pipek (@janpipek)
* Kees Hink (@khink)
* @terra-alex

Thank you!
